# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"imageFromS3": "Images.ipynb",
         "imageFromUrl": "Images.ipynb",
         "imageToS3": "Images.ipynb",
         "resizeImage": "Images.ipynb",
         "showImgS3": "Images.ipynb",
         "async_wrap": "async.ipynb",
         "asyncMap": "async.ipynb",
         "asyncAwaitMap": "async.ipynb",
         "printDict": "dictUtil.ipynb",
         "allKeysInDict": "dictUtil.ipynb",
         "filterDt": "dictUtil.ipynb",
         "stripDict": "dictUtil.ipynb",
         "hashDict": "dictUtil.ipynb",
         "saveDictToFile": "dictUtil.ipynb",
         "loadDictFromFile": "dictUtil.ipynb",
         "saveStringToFile": "dictUtil.ipynb",
         "loadStringFromFile": "dictUtil.ipynb",
         "genSchema": "dictUtil.ipynb",
         "printYaml": "dictUtil.ipynb",
         "errorString": "exception.ipynb",
         "getDfHash": "pdUtils.ipynb",
         "saveLocalCache": "pdUtils.ipynb",
         "saveLocalHash": "pdUtils.ipynb",
         "loadLocalCache": "pdUtils.ipynb",
         "loadLocalHash": "pdUtils.ipynb",
         "saveRemoteHash": "pdUtils.ipynb",
         "saveRemoteCache": "pdUtils.ipynb",
         "loadRemoteCache": "pdUtils.ipynb",
         "loadRemoteHash": "pdUtils.ipynb",
         "PandasDataFrameAttribute": "pdUtils.ipynb",
         "forceType": "pdUtils.ipynb",
         "SchemaAttribute": "pynamodbAttributes.ipynb",
         "extraDocsString": "pynamodbAttributes.ipynb",
         "SuperModel": "pynamodbAttributes.ipynb",
         "createData": "pynamodbAttributes.ipynb",
         "getData": "pynamodbAttributes.ipynb",
         "updateData": "pynamodbAttributes.ipynb",
         "getSchemaPath": "schema.ipynb",
         "validateUrl": "schema.ipynb",
         "getTypes": "schema.ipynb",
         "typeMapJsonSchema": "schema.ipynb",
         "typeMap": "schema.ipynb",
         "getSecret": "secrets.ipynb",
         "shorten": "shortenLInk.ipynb",
         "url": "shortenLInk.ipynb",
         "Timer": "timer.ipynb",
         "start_timer": "timer.ipynb",
         "reset_timer": "timer.ipynb",
         "print_time": "timer.ipynb",
         "print_reset": "timer.ipynb",
         "add_method": "wrappers.ipynb",
         "add_static_method": "wrappers.ipynb",
         "add_class_method": "wrappers.ipynb"}

modules = ["images.py",
           "asyncUtil.py",
           "dictUtil.py",
           "exception.py",
           "pdUtils.py",
           "pynamodb.py",
           "schema.py",
           "secrets.py",
           "shortenLink.py",
           "timer.py",
           "wrappers.py"]

doc_url = "https://thanakijwanavit.github.io/nicHelper/"

git_url = "https://github.com/thanakijwanavit/nicHelper/tree/master/"

def custom_doc_links(name): return None
