# AUTOGENERATED! DO NOT EDIT! File to edit: exception.ipynb (unless otherwise specified).

__all__ = ['errorString']

# Cell
import traceback

# Cell
def errorString():
  return traceback.format_exc()